##  Limitations
Since SAP LeanIX uses data from SAP Cloud ALM, it can only discover systems and services that SAP Cloud ALM supports. To view the full list of supported solutions, refer to [SAP Cloud ALM Supported Solutions](https://help.sap.com/docs/cloud-alm/setup-administration/supported-solutions "https://help.sap.com/docs/cloud-alm/setup-administration/supported-solutions").
In addition, the integration does not support the following SAP Cloud ALM systems and services:
  * SAP SaaS Products: BTP (PaaS) services, BTP sub-accounts, niche products, and certain product modules are not discovered. RISE Starter Systems are also excluded.
  * SAP Private Cloud Products: Filters out HANA, BTP, and other niche products, because these are categorized as infrastructure. This includes all systems hosted in [NS2![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsapns2.com%2Fproduct-support%2F "https://sapns2.com/product-support/").
  * SAP On-Premise Products: Filters out S/4HANA and S/4HANA Cloud systems to exclude cloud-based offerings from on-premise discovery results.


If some services aren’t visible in SAP Cloud ALM, your organization may not have subscribed to them in the SAP BTP cockpit. If you are subscribed to the services but they are still missing, refer to the [Troubleshooting Guide![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.sap.com%2Fen%2Falm%2Fsap-cloud-alm%2Foperations%2Fexpert-portal%2Fcalm-op-troubleshooting%2Flms-troubleshooting.html%3FanchorId%3Dsection_665299547_co "https://support.sap.com/en/alm/sap-cloud-alm/operations/expert-portal/calm-op-troubleshooting/lms-troubleshooting.html?anchorId=section_665299547_co").
